# KPIs
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/kpis#overview)
  * [KPI Types](https://help.sap.com/docs/leanix/ea/kpis#kpi-types)
  * [How KPIs Are Calculated](https://help.sap.com/docs/leanix/ea/kpis#how-kpis-are-calculated)
  * [Permissions](https://help.sap.com/docs/leanix/ea/kpis#permissions)
  * [Configuring KPIs](https://help.sap.com/docs/leanix/ea/kpis#configuring-kpis)
  * [Managing KPIs](https://help.sap.com/docs/leanix/ea/kpis#managing-kpis)
  * [Adding KPIs to Dashboards](https://help.sap.com/docs/leanix/ea/kpis#adding-kpis-to-dashboards)
  * [Dashboards with Predefined KPIs](https://help.sap.com/docs/leanix/ea/kpis#dashboards-with-predefined-kpis)


View all
Configure KPIs and display them on dashboards to track enterprise architecture metrics.
